@@ -249,9 +249,6 @@ c
       elseif(ksib .eq. 27) then
          code = krho
          charge = 0
-      elseif(ksib .eq. 32) then
-         code = komega
-         charge = 0
       elseif(ksib .eq. 33) then
          code = kphi
          subcode = regptcl
