@@ -27,11 +27,17 @@
       endif
       tg.fm.p(4) = tg.mass
       tg.fm.p(1:3)= 0.
+!        if 0 K.E, only elastic events are obtained-->loop
+      if(  pj.fm.p(4) - pj.mass <=0. ) then
+         pj.fm.p(4) = 0.001 + pj.mass
+      endif
 
       ok = .false.
       do while (.not. ok)
          call cjamini(pj, tg, sig)
          call cjam(pj, a, ntp, inela)
+
+
 c          jam cannot disable elastic collision.
 c        for non heavy, we can use total x-section
 c        which includes elastic one, but for heavy
@@ -254,13 +260,14 @@ c               incorrect and 1 must be used
             endif
 
             call ckf2cos(k(2,i), code, subcode, charge)
-            ntp = ntp + 1
-            call cmkptc(code, subcode, charge, a(ntp))
-            a(ntp).fm.p(1) = p(1,i)
-            a(ntp).fm.p(2) = p(2,i)
-            a(ntp).fm.p(3) = p(3,i)
-            a(ntp).fm.p(4) = p(4,i)  ! jam is T.E  (K.E is false).
-
+            if( code /=  krare ) then 
+               ntp = ntp + 1
+               call cmkptc(code, subcode, charge, a(ntp))
+               a(ntp).fm.p(1) = p(1,i)
+               a(ntp).fm.p(2) = p(2,i)
+               a(ntp).fm.p(3) = p(3,i)
+               a(ntp).fm.p(4) = p(4,i) ! jam is T.E  (K.E is false).
+            endif
 c            write(*,*) i, k(2,i), p(1,i), p(2,i), p(3,i),
 c     *             p(4,i), p(5,i)
          endif
