@@ -29,6 +29,7 @@ c           get one particle from stack
 c                     icon=0; alive, 1 E<Emin, 2 long flight 3 h>H 4 h<L
 c                             5 angle>limit
 c            AS generation. 
+
          if(ObserveAS .and. icon .le. 1 ) then
             if(TrackBefMove.p.code .eq. kelec) then
                if(TrackBefMove.asflag .eq. 0) then
@@ -316,6 +317,7 @@ C           if you activate the next routine, Epics will have link problem!!!
 #include  "Ztrackp.h"
 #include  "Zobs.h"
 #include  "Zobsv.h"
+#include  "Zevhnv.h"
 
       logical deb
       common /cdebug/deb
@@ -328,10 +330,12 @@ C           if you activate the next routine, Epics will have link problem!!!
       nc = nc + 1
 c      if(nc .gt. 750) then
 c      if( deb) then
-
+            write(0,*) ' ActiveModel=',ActiveMdl
             write(0,*) str, ' code=',TrackBefMove.p.code,
-     *         ' cg',TrackBefMove.p.charge,
-     *         ' e=', TrackBefMove.p.fm.p(4), ' stat=',MoveStat
+     *         ' sub',TrackBefMove.p.subcode,
+     *         ' chg',TrackBefMove.p.charge
+            write(0,*) 'Px,y,z e=', TrackBefMove.p.fm.p(1:4)
+            write(0,*)  'Move stat=',MoveStat
             write(0, *) ' where', TrackBefMove.where
             write(0,*)  ' h==', TrackBefMove.pos.height,
      *       ' d=', TrackBefMove.pos.depth
